/// <reference types="node" />
declare const utils: {
    /**
     * Convert the given byte array to a hexadecimal string.
     *
     * @param bytes - An array of bytes.
     * @returns An encoded hexadecimal string.
     */
    toHex(bytes: Uint8Array): string;
    /**
     * Convert the given hexadecimal string to a byte array.
     *
     * @param hex - A hexadecimal string.
     * @returns A decoded byte array.
     */
    toBytes(hex: string): Uint8Array;
    /**
     * Check if the given string is valid hex.
     *
     * @param input - The input to check.
     * @returns True if the input is valid hex, otherwise false.
     */
    isHex(input: string): boolean;
    /**
     * Compute the SHA512 half hash of the given bytes.
     *
     * @param bytes - The array of bytes to hash.
     * @returns The hash of the input.
     */
    sha512Half(bytes: Uint8Array): Uint8Array;
    /**
     * Convert a buffer to a hex string.
     *
     * @param buffer - The buffer to convert.
     * @returns A hex string representing the buffer.
     */
    hexFromBuffer(buffer: Buffer): string;
};
export default utils;
